# モジュール読み込み *******************************************************
import time
import subprocess
# ｔime:時間に関するPython標準モジュールです。
# subproces:プロセス管理に関するPython標準モジュールです。

# CPU異常検知　クロックダウン監視　*******************************************
cpu_lowvolt = 0
cpu_clockdown = 0
# CPU電圧低下、クロックダウン検出フラグです。異常を検出したら1にします。


def siro_cpu_clockdown():
    # CPU電圧低下・クロックダウンを検知する関数を定義しています。

    global cpu_clockdown, cpu_lowvolt

    cmd = "vcgencmd get_throttled"
    # Raspberry PiのCPU電圧低下・クロックダウンの有無を調べるコマンドです。

    result = subprocess.check_output(cmd.split())
    # コマンドを実行してその結果を取得しています。

    result = result.decode("utf-8")
    # コマンドの結果をデコードして文字列に変換しています。

    # コマンド実行結果は以下のようになります。
    # ”throttled=0x******”
    # 0x0	    正常
    # 0x50000   過去に低電圧状態になった。現在は正常
    # 0x50005   現在、低電圧状態
    # 0x80000   過去に熱によりクロックダウンした。現在は正常
    # 0x80008   現在、熱によりクロックダウン中
    # 0xD000D   現在、低電圧状態かつ熱によりクロックダウン中

    print(result)

    if ("0x50005" in result):  # 現在、低電圧状態にある。
        cpu_lowvolt = 1
        cpu_clockdown = 0
    elif ("0x80008" in result):  # 現在、熱によりクロックダウンしている。
        cpu_lowvolt = 0
        cpu_clockdown = 1
    elif ("0xD000D" in result):  # 現在、低電圧状態かつ熱によりクロックダウンしている。
        cpu_lowvolt = 1
        cpu_clockdown = 1
    elif (result == "throttled=0x0\n"):  # 異常なし
        cpu_clockdown = 0
        cpu_lowvolt = 0
    # 電圧低下、クロックダウンを検知したら検出フラグを立てます。


# メイン処理 *************************************************************
try:
    while True:
        siro_cpu_clockdown()
        # 定義した関数を使ってCPUの異常を確認します。

        print("CPUクロックダウン:", cpu_clockdown)
        print("CPU電圧低下:", cpu_lowvolt)
        # 結果を表示します。

        time.sleep(3)
        # ３秒ごとに実行します。

# 終了処理　**************************************************************
# Ctrl + C キーボード割り込み
except KeyboardInterrupt as reigai:
    print("Ctrl C ........")

finally:  # 終了処理
    print("SIRO stopping............")

# End of program ●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●
