# モジュール読み込み ******************************************************
import time
from Adafruit_BME280 import *
# time: 時間に関するPython標準モジュールです。
# Adafruit_BME280:センサメーカー(Adafruit)がGitHub（https://github.com/adafruit/Adafruit_Python_BME280）に公開しているPythonモジュールです。
# プロジェクトフォルダ（筆者の場合は/home/kuro/kurosSIRO）に保存します。


# 気温/湿度検知　BME280　 ***********************************************
BME280_sensor = BME280(t_mode=BME280_OSAMPLE_8, p_mode=BME280_OSAMPLE_8,
                       h_mode=BME280_OSAMPLE_8)
# クラスのインスタンス生成、初期化を行っています。

temp = 0.0  # 温度
humid = 0.0  # 湿度
temp_offset = -2.1
humid_offset = 2.0
WBGT = 0.0  # 暑さ指数
# 変数を定義しています。
# 家の温湿度計と差があるのでオフセットをつけて調整しています。

# メイン処理 *************************************************************
try:
    while True:
        temp = BME280_sensor.read_temperature() + temp_offset
        humid = BME280_sensor.read_humidity() + humid_offset
        # クラスメソッドを使ってセンサから気温と湿度を読み込んでいます。

        WBGT = 0.725*temp + 0.0368*humid + 0.00364*temp*humid - 3.246
        # WBGT（暑さ指数）は熱中症予防を目的とした湿度、日射・輻射など周辺の熱環境、気温の３つを取り入れた指標です。
        # 本来のWBGT計算式は複雑なのですが、ここでは屋内前提の近似式を使っています。

        print("temp:{:.1f}".format(temp))
        print("humid:{:.1f}".format(humid))
        print("WBGT:{:.1f}".format(WBGT))
        # 気温と湿度とWBGTを表示しています。

        time.sleep(3)
        # 3秒ごとに繰り返します。

# 終了処理　**************************************************************
# Ctrl + C キーボード割り込み
except KeyboardInterrupt as reigai:
    print("Ctrl C ........")

finally:  # 終了処理
    print("SIRO stopping............")

# End of program ●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■
