# モジュール読み込み ******************************************************
import cv2  # openCV
# cv2: OpenCVのPythonモジュールです。

# 顔認識  ***************************************************************
face_cascade = \
    cv2.CascadeClassifier('/home/kuro/kurosSIRO/haarcascades/haarcascade_frontalface_alt.xml')
# 顔認識学習モデル（カスケード分類器）をファイル名で指定して読み込んでいます。

cap = cv2.VideoCapture(0)
# クラスのインスタンス生成

cap.set(3, 640)  # 画像サイズ WIDTH
cap.set(4, 480)  # 画像サイズ HEIGHT
# カメラの解像度を設定しています。
# 解像度を大きくすると画像が鮮明になりますが処理動作が遅くなります。

cap.set(cv2.CAP_PROP_FPS, 30)
# FPSを設定しています。
# 使用したUSBカメラはFPS30で固定なので設定してもあまり意味がないのですが一応明示しています。

cap.set(cv2.CAP_PROP_BUFFERSIZE, 1)
# バッファサイズを最小の１に設定しています。
# こうすることでバッファ分のフレームの遅延がなくなります。

minW = 50
minH = 50
# 認識可能な顔のサイズを設定しています。
# 大きくすると遠くの顔が認識できなくなりますが誤認識が少なくなります。
# 逆に小さくすると遠くの顔も認識できる様になりますが壁の模様を顔と間違える等の誤認識が増えます。

# メイン処理 *************************************************************
try:
    while True:

        ret, frame = cap.read()
        # カメラ画像を取得しています。

        grayimg = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
        # 顔認識を行う前に画像をモノクロ処理して情報量を減らしています。

        facerect = face_cascade.detectMultiScale(grayimg, minSize=(minW, minH))
        # 顔認識を行っています。

        if len(facerect) > 0:
        # 顔を見つけたら顔の部分を四角で囲ってターミナルに”かおはっけん”と表示します。

            for (x, y, w, h) in facerect:
                cv2.rectangle(frame, (x, y), (x+w, y+h), (255, 0, 0), 2)  # 顔検出箇所を□で囲む
                print("かおはっけん")

        cv2.imshow('camera capture', frame)
        # カメラ画像をウインドウに表示させています。

        cv2.waitKey(100)
        # 処理周期を100msecに設定しています。

# 終了処理 **************************************************************
# Ctrl + C キーボード割り込み
except KeyboardInterrupt as reigai:
    print("Ctrl C ........")

finally:  # 終了処理
    print("SIRO stopping............")

    cap.release()
    # OpenＣＶを終了しカメラデバイスを解放します。
    cv2.destroyAllWindows()
    # カメラ画像表示ウインドウを閉じます。

# End of program ●▲■●▲■●▲■●▲■■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■
