# モジュール読み込み *******************************************************
import time
import RPi.GPIO as GPIO
# ｔime: 時間に関するPython標準モジュールです。
# RPi.GPIO: Raspberry PiのGPIO(汎用入出力)を制御するためのPythonモジュールです。

# GPIO 設定　************************************************************
GPIO.setmode(GPIO.BCM)  # GPIO番号で指定するモード
# GPIOを使用する際にポート番号で指定するかピン番号で指定するかを設定しています。
# 例えばGPIO2はポート番号で指定すると”２”、ピン番号で指定すると”３”になります。
# ここではポート番号で指定するモードを選択しています。

# 障害物検知 ************************************************************
USS_TRIG = 24  # 超音波発生トリガー
USS_ECHO = 25  # エコー受信
# 超音波センサの接続先とGPIOのポート番号を紐づけています。

GPIO.setup(USS_TRIG, GPIO.OUT)
GPIO.setup(USS_ECHO, GPIO.IN)
# トリガー送信を出力、エコー受信を入力に設定しています。

uss_distance = 0  # 障害物までの距離 cm
# 変数を定義しています。

# メイン処理 *************************************************************
try:
    while True:
        print("超音波発信")

        GPIO.output(USS_TRIG, GPIO.HIGH)
        time.sleep(0.00001)
        GPIO.output(USS_TRIG, GPIO.LOW)
        # トリガー信号（10μ秒）を打って超音波を送信しています。

        while GPIO.input(USS_ECHO) == GPIO.LOW:
            uss_start = time.time()
        # 照射エコーを検知しなくなるまで待機しています。

        while GPIO.input(USS_ECHO) == GPIO.HIGH:
            uss_end = time.time()
        # 反射エコーを検知するまで待機しています。

        uss_distance = (uss_end - uss_start)*17015
        # 超音波を送信してから障害物に当たって跳ね返った反射波を受信するまでの時間から障害物までの距離を算出しています。
        # 17015は34029 cm/s (音速) ÷２です。超音波が往復して帰ってくるので２で割っています。

        print("距離:", int(uss_distance), "cm")
        # 算出した障害物までの距離を表示しています。

        time.sleep(1)
        # 1秒ごとに測定を行います。


# 終了処理　**************************************************************
# Ctrl + C キーボード割り込み
except KeyboardInterrupt as reigai:
    print("Ctrl C ........")

finally:  # 終了処理
    print("SIRO stopping............")
    GPIO.cleanup()  # GPIO初期化

# End of program ●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■
