# モジュール読み込み ******************************************************
import time
import os
from flask import Flask, render_template, request, redirect, session
import threading
# time:時間に関するPython標準モジュールです。
# os:os機能に関するPython標準モジュールです。
# threading:マルチスレッド処理に関するPython標準モジュールです。
# flask:FlaskのPythonモジュールです。


# Webアプリ flask *******************************************************
id_pwd = {"********": "*********"}
# WebアプリのログインＩＤとパスワードを設定しています。*****は任意に設定可能です。

app = Flask(__name__, static_folder='/home/kuro/kurosSIRO/data',
            template_folder='/home/kuro/kurosSIRO/templates')
# Flaskクラスのインスタンスを生成しています。同時にHTML他コンテンツファイルの保存場所を指定しています。
# テンプレートファイルの保存場所はデフォルトのままですが、一応、明記しておきます。

key = os.urandom(21)
app.secret_key = key
# ログイン情報のセッション管理に使用する秘密鍵を生成しています。


# ルーティング設定 *********************************************************
# Webブラウザからのリクエストに対してWebサーバーがどのような処理を行うかを設定します。

# ルート ************************************
@app.route('/')
# Webブラウザがルート（/）をリクエストした場合の処理を設定します。
def login_check():

    if not session.get('login'):
        return redirect('/login')
        # loginセッションがFalseすなわちログイン前であればログイン画面（/login）に移行します。
    else:
        return redirect('/menu')
        # loginセッションがTrueすなわちログイン済であればメニュー画面（/menu）に移行します。


# ログイン画面 *******************************
@app.route('/login')
# Webブラウザがログイン画面（/login）をリクエストした場合の処理を設定します。
def login():

    return render_template("login.html")
    # Flaskのレンダリングテンプレートという機能を使ってログイン画面を表示します。
    # HTMLファイルは事前に所定のフォルダ（筆者の場合は/home/kuro/kurosSIRO/templates）に保存しておきます。
    # HTMLファイル（login.html）の中身については後ほど解説します。


# ログインチェック ****************************
@app.route('/logincheck', methods=['POST'])
# WebブラウザがPOSTメソッドで/logincheckをリクエストした場合の処理を設定します。
# 上記のリクエストはログイン画面でログインボタンを押した場合に発生します。
# その動作はHTMLファイル（login.html）側での設定になりますので後ほど解説します。
def logincheck():

    user_id = request.form['user_id']
    password = request.form['password']
    # POSTされたフォーム入力データ（ユーザーIDとパスワード）を取得しています。

    if user_id in id_pwd:
        if password == id_pwd[user_id]:
            session['login'] = True
        else:
            session['login'] = False
    else:
        session['login'] = False
    # ユーザーID、パスワードともに一致すればloginセッションをTrueにします。

    if not session.get('login'):
        return render_template("login.html", warning="ユーザーID,パスワードが一致しません。")
        # loginセッションがFalseなら"ユーザーID,パスワードが一致しません。"と警告します。
        # Flaskのレンダリングテンプレート機能でlogin.htmlの中の｛｛warning｝｝という変数に警告文を反映させます。
    else:
        return redirect('/menu')
        # loginセッションがTrueならメニュー画面(/menu)に移行します。


# メニュー画面 *************************
@app.route('/menu')
# Webブラウザがメニュー画面（/menu）をリクエストした場合の処理を設定します。
def menu():

    if not session.get('login'):
        return redirect('/login')
        # loginセッションがFalseすなわちログイン前ならログイン画面に移行します。
    else:
        return render_template("menu.html")
        # loginセッションがTrueすなわちログイン済であれば
        # Flaskのレンダリングテンプレート機能を使ってメニュー画面を表示します。


# ログアウト処理 **************************
@app.route('/logout')
# Webブラウザが/logoutをリクエストした場合の処理を設定します。
# 上記のリクエストはメニュー画面でlogoutボタンを押したとき場合に発生します。
# その動作はHTMLファイル（menu.html）側での設定になりますので後ほど解説します。
def logout():

    session.pop('login', None)
    # loginセッションを削除します。

    return redirect('/login')
    # ログイン画面に移行します。


# webサーバーをサブスレッドで起動　*******************************************
# ルーティング設定が終わったらWebサーバーを起動します。
# Webサーバーの起動はメイン処理と並行処理となるようサブスレッドで起動します。

def httpserver():
    # webサーバーの起動処理をまとめた関数を定義します。

    app.run(host='0.0.0.0', port=5000)
    # Webサーバーを起動しています。
    # host=’0,0,0,0’と指定することでローカルネットワークの外からもWebサーバーにアクセスすることが可能になります。
    # 0.0.0.0はすべてのホストからのアクセスを受け付けることを意味します。
    # デフォルト設定では自分自身からでしかアクセスできないようになっています。
    # ポート番号を5000に指定しています。デフォルトでも5000なのですが、一応、明示しておきます。


th_flask = threading.Thread(target=httpserver)
# 定義した関数をサブスレッドに指定しています。

th_flask.setDaemon(True)
# この設定をしておくとメインスレッドが停止した際にサブスレッドも一緒に強制終了されます。

th_flask.start()
# サブスレッドの処理を開始します。

print("SIRO Web application by Flask start...")

# メイン処理   ***********************************************************
try:
    while True:
        print("SIRO Web application ......",)
        time.sleep(10)
        # 適当なメッセージを１０秒ごとに表示しています。

# 終了処理　**************************************************************
# Ctrl + C キーボード割り込み
except KeyboardInterrupt as reigai:
    print("Ctrl C ........")

finally:  # 終了処理
    print("SIRO stopping............")

# End of program ●▲■●▲■●▲■●▲■■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■●▲■
